@@ -1,4 +1,4 @@
-from typing import List
+from typing import List, Set
 
 from extract_emails.email_filters import EmailFilterInterface
 from .domains import TOP_LEVEL_DOMAINS
@@ -11,7 +11,7 @@ class DefaultEmailFilter(EmailFilterInterface):
     """
 
     def __init__(self):
-        self.checked_emails: List[str] = []
+        self.checked_emails: Set[str] = set()
 
     def filter(self, emails: List[str]) -> List[str]:
         """
@@ -27,6 +27,6 @@ class DefaultEmailFilter(EmailFilterInterface):
                 continue
             if email in self.checked_emails:
                 continue
-            self.checked_emails.append(email)
+            self.checked_emails.add(email)
             filtered_emails.append(email)
         return filtered_emails
